==> hydrogen_1.0.0~rc1.orig.tar.gz: hydrogen-1.0.0-rc1/src/gui/src/SongEditor/PlaybackTrackWaveDisplay.h <==
/*
 * Hydrogen
 * Copyright(c) 2002-2008 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 *
 * http://www.hydrogen-music.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef PLAYBACKTRACKWAVE_DISPLAY
#define PLAYBACKTRACKWAVE_DISPLAY

#include <QtGui>
#if QT_VERSION >= 0x050000
#  include <QtWidgets>
#endif
#include <hydrogen/object.h>
#include "../InstrumentEditor/WaveDisplay.h"

namespace H2Core
{
	class InstrumentLayer;
}

class PlaybackTrackWaveDisplay : public WaveDisplay
{
    H2_OBJECT
	Q_OBJECT

	public:
		PlaybackTrackWaveDisplay(QWidget* pParent);
		~PlaybackTrackWaveDisplay() = default;

		void	updateDisplay( H2Core::InstrumentLayer *pLayer ) override;
		
	public slots:
		virtual void dragMoveEvent(QDragMoveEvent *event) override;
		virtual void dropEvent(QDropEvent *event) override;
		virtual void dragEnterEvent(QDragEnterEvent * event) override;
};

#endif

==> hydrogen-1.2.3.tar.gz: hydrogen-1.2.3/src/gui/src/SongEditor/PlaybackTrackWaveDisplay.h <==
/*
 * Hydrogen
 * Copyright(c) 2002-2008 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 * Copyright(c) 2008-2024 The hydrogen development team [hydrogen-devel@lists.sourceforge.net]
 *
 * http://www.hydrogen-music.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see https://www.gnu.org/licenses
 *
 */

#ifndef PLAYBACKTRACKWAVE_DISPLAY
#define PLAYBACKTRACKWAVE_DISPLAY

#include <QtGui>
#include <QtWidgets>
#include <memory>

#include <core/Object.h>
#include "../InstrumentEditor/WaveDisplay.h"

namespace H2Core
{
	class InstrumentLayer;
}

/** \ingroup docGUI*/
class PlaybackTrackWaveDisplay : public WaveDisplay
{
    H2_OBJECT(PlaybackTrackWaveDisplay)
	Q_OBJECT

	public:
		explicit PlaybackTrackWaveDisplay(QWidget* pParent);
		~PlaybackTrackWaveDisplay();

		void	updateDisplay( std::shared_ptr<H2Core::InstrumentLayer> pLayer ) override;
	void updatePosition( float fTick );
		
	public slots:
		virtual void dragMoveEvent(QDragMoveEvent *event) override;
		virtual void dropEvent(QDropEvent *event) override;
		virtual void dragEnterEvent(QDragEnterEvent * event) override;
	virtual void paintEvent(QPaintEvent * event) override;

private: 
	QPixmap *m_pBackgroundPixmap;
	/** Cached position of the playhead.*/
	float m_fTick;
};

#endif
